// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_CHROMEOS_LOGIN_WEB_PAGE_SCREEN_H_
#define CHROME_BROWSER_CHROMEOS_LOGIN_WEB_PAGE_SCREEN_H_

#include "base/basictypes.h"
#include "base/compiler_specific.h"
#include "base/timer.h"
#include "chrome/browser/chromeos/login/screen_observer.h"
#include "content/public/browser/web_contents_delegate.h"

namespace chromeos {

// Base class for wizard screen that holds web page.
class WebPageScreen : public content::WebContentsDelegate {
 public:
  explicit WebPageScreen();
  virtual ~WebPageScreen();

  // Exits from the screen with the specified exit code.
  virtual void CloseScreen(ScreenObserver::ExitCodes code) = 0;

 protected:
  // content::WebContentsDelegate implementation:
  virtual bool HandleContextMenu(
      const content::ContextMenuParams& params) OVERRIDE;

  // Called by |timeout_timer_|. Stops page fetching and closes screen.
  virtual void OnNetworkTimeout();

  // Start/stop timeout timer.
  void StartTimeoutTimer();
  void StopTimeoutTimer();

 private:
  // Timer used for network response timeout.
  base::OneShotTimer<WebPageScreen> timeout_timer_;

  DISALLOW_COPY_AND_ASSIGN(WebPageScreen);
};

}  // namespace chromeos

#endif  // CHROME_BROWSER_CHROMEOS_LOGIN_WEB_PAGE_SCREEN_H_
